@@ -17,8 +17,12 @@
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int sgscmn_0_(int n__, integer *nc, integer *nmax)
 {
-    extern /* Subroutine */ int swcmll_(void), swqcmn_(integer *), swistx_(
-	    char *, integer *, ftnlen);
+    static integer iws;
+    static logical lcmch, lfcatr;
+    extern /* Subroutine */ int swclch_(void), swqfcc_(logical *), msgdmp_(
+	    char *, char *, char *, ftnlen, ftnlen, ftnlen), swcmll_(void), 
+	    swiget_(char *, integer *, ftnlen), swlget_(char *, logical *, 
+	    ftnlen), swqcmn_(integer *), swistx_(char *, integer *, ftnlen);
 
     switch(n__) {
 	case 1: goto L_sgqcmn;
@@ -26,6 +30,18 @@
 
     swcmll_();
     swistx_("ICLRMAP", nc, (ftnlen)7);
+    swqfcc_(&lfcatr);
+    swlget_("LCMCH", &lcmch, (ftnlen)5);
+    swiget_("IWS", &iws, (ftnlen)3);
+    if (iws >= 1 && iws <= 4) {
+	if (lcmch) {
+	    if (! lfcatr || iws == 1) {
+		msgdmp_("W", "SGSCMN", "COLORMAP MIGHT NOT CHANGE IMMEDIATEL"
+			"Y.", (ftnlen)1, (ftnlen)6, (ftnlen)38);
+	    }
+	    swclch_();
+	}
+    }
     return 0;
 /* ----------------------------------------------------------------------- */
 
